@@ -3,7 +3,6 @@
 #include <Rinternals.h>
 #include <math.h>
 #include <vector>
-#include "dists.h"
 #include "Pp.h"
 
 #ifndef GRAPH_H_
@@ -21,20 +20,30 @@ public:
 	int    *dbg;
 	double *prepR;
 	int    *gtype;
+	int    *inc;
 	double  mdeg;
 	int 	preEdges;
+	double *weightMatrix;
+	SEXP *other, *env;
 	std::vector<std::vector<int> > nodelist;
+	std::vector<int> typeIncluded;
+	double (Graph::*getTypeToTypeWeightp)(int*, int*);
+
 	Graph();
 	virtual ~Graph();
 
-	void Init(Pp *pp0, int *gtype0, double *par, double *prepR, int *doDists, double *preDists, int *toroidal, int *dbg );
+	void Init(Pp *pp0, int *gtype0, double *par, double *prepR, int *doDists, double *preDists, int *toroidal, int *inc, double *, int *dbg, SEXP *, SEXP *);
 	void setNodelist(std::vector<std::vector<int> > *nodelist_new);
 	void setNodelist(SEXP);
 	void addNew(int , int);
+	double getTypeToTypeWeight(int *, int *);
+	double getTypeToTypeWeight_all1(int *t1, int *t2);
+	double getTypeToTypeWeight_weighted(int *t1, int *t2);
 	void sg_calc();
 
 	void sg_geometric();
 	void sg_geometric(double *);
+	void sg_big_geometric();
 	void sg_shrink_geometric(double *);
 	void sg_mass_geometric();
 	void sg_knn();
@@ -48,6 +57,7 @@ public:
 	void sg_RNG();
 	void sg_CCC();
 	void sg_STIR();
+	void sg_random();
 
 	void sg_cut(double *R);
 	void sg_prune(double *lev);
